@@ -2,7 +2,7 @@
 Converter configuration constants
 """
 
-NIX_FILE_OUTPUT_DIR = "../converted/"
+NIX_FILE_OUTPUT_DIR = "converted/"
 NIX_FILE_EXTENSION = ".nix"
 NIX_BLOCK_NAME = "EEG Data"
 
